pyliven.exceptions API documentation

# Module `pyliven.exceptions`

## Classes

`class IllegalOperationError`

  Raised when an illegal operation is performed on LiveNum

  Expand source code

      class IllegalOperationError(Exception):
          """Raised when an illegal operation is performed on LiveNum"""
          def __init__(self):
              super().__init__("Arithmetic operation on LiveNum only permitted with int, float and LiveNum objects")

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ImproperCoreValueError`

  Raised when an improper core value is passed to LiveNum

  Expand source code

      class ImproperCoreValueError(Exception):
          """Raised when an improper core value is passed to LiveNum"""
          def __init__(self):
              super().__init__("Core value must be a number or another LiveNum object")

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ImproperSideValueError`

  Raised when an improper side value is passed to LiveNum

  Expand source code

      class ImproperSideValueError(Exception):
          """Raised when an improper side value is passed to LiveNum"""
          def __init__(self):
              super().__init__("Side must be a number, another LiveNum object, or None")

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class ImproperUpdateValueError`

  Raised when an improper value is passed to update method

  Expand source code

      class ImproperUpdateValueError(Exception):
          """Raised when an improper value is passed to update method"""
          def __init__(self):
              super().__init__("Update value must be a number (int or float)")

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException
`class MissingOperatorOrSideError`

  Raised when operator or side is not provided together

  Expand source code

      class MissingOperatorOrSideError(Exception):
          """Raised when operator or side is not provided together"""
          def __init__(self):
              super().__init__("Operator and Side must be provided together")

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException